import { ReducersMapObject } from 'redux';
import SagaWatcher from '@overflow/commons/redux/saga/SagaWatcher';

import signInReducer from '@overflow/member/redux/reducer/signIn';
import signUpReducer from '@overflow/member/redux/reducer/signUp';

import readAllProbeReducer from '@overflow/probe/redux/reducer/readAllByDomain';
import readProbeReducer from '@overflow/probe/redux/reducer/read';

import readNoAuthProbeReducer from '@overflow/noauthprobe/redux/reducer/read_all_by_domain';

import readAllTargetByProbeReducer from '@overflow/target/redux/reducer/readAllByProbe';
import readAllTargetByDomainReducer from '@overflow/target/redux/reducer/read_all_by_domain';
import readTargetReducer from '@overflow/target/redux/reducer/read';

import sensorReadAllByTargetReducer from '@overflow/sensor/redux/reducer/read_all_by_target';
import sensorReadAllByDomainReducer from '@overflow/sensor/redux/reducer/read_all_by_domain';
import SensorReadReducer from '@overflow/sensor/redux/reducer/read';
import SensorItemReadAllBySensorReducer from '@overflow/sensor/redux/reducer/item_read_all_by_sensor';

import readMachineReducer from '@overflow/infra/redux/reducer/machine_read';
import readHostReducer from '@overflow/infra/redux/reducer/host_read';
import readOSReducer from '@overflow/infra/redux/reducer/os_read';
import readServiceReducer from '@overflow/infra/redux/reducer/service_read';

import CrawlerReadAllByTargetReducer from '@overflow/meta/redux/reducer/crawler_read_all_by_target';
import CrawlerAuthInputsReducer from '@overflow/meta/redux/reducer/crawler_auth_inputs';

import MetaSensorItemReadAllReducer from '@overflow/meta/redux/reducer/sensor_item_read_all';
import MetaSensorItemTypeReadAllReducer from '@overflow/meta/redux/reducer/sensor_item_type_read_all';

import AsyncRequest from '@overflow/app/redux/saga/AsyncRequest';

// Container Configuration
export interface ContainerConfig {
  placeholderID: string;
}
const containerConfig: ContainerConfig = {
  placeholderID: 'appContainer',
};

// RPC Server Configuration
export interface RPCConfig {
  url: string;
}
const rpcConfig: RPCConfig = {
  url: 'ws://192.168.1.209:18081/rpc',
};

// Redux Configuration
export interface ReduxConfig {
  state: ReduxState;
  reducerMaps: ReducersMapObject[];
  sagaWatchers: Class<SagaWatcher>[];
}
export interface ReduxState {

}
const reduxState: ReduxState = {};



const reduxConfig: ReduxConfig = {
  state: reduxState,
  reducerMaps: [
    signInReducer,
    readAllProbeReducer,
    readProbeReducer,
    sensorReadAllByTargetReducer,
    sensorReadAllByDomainReducer,
    SensorReadReducer,
    signUpReducer,
    SensorItemReadAllBySensorReducer,
    readAllTargetByProbeReducer,
    readAllTargetByDomainReducer,
    readTargetReducer,
    readNoAuthProbeReducer,
    readMachineReducer,
    readHostReducer,
    CrawlerReadAllByTargetReducer,
    CrawlerAuthInputsReducer,
    MetaSensorItemReadAllReducer,
    MetaSensorItemTypeReadAllReducer,
    readOSReducer,
    readServiceReducer,
  ],
  sagaWatchers: [
    AsyncRequest,
  ],
};


// Configuration
export interface Config {
  container: ContainerConfig;
  rpc: RPCConfig;
  redux: ReduxConfig;
}

const config: Config = {
  container: containerConfig,
  rpc: rpcConfig,
  redux: reduxConfig,
};

export default config;
